Crate snarkvm_circuit_program

Crate snarkvm_circuit_program 

Structs

Ciphertext
DynamicFuture
A dynamic future is a fixed-size representation of a future. Like static Futures, a dynamic future contains a program name, program network, and function name. These are however represented as Field elements as opposed to Identifiers to ensure a fixed size. Dynamic futures also store a checksum of the arguments to the future instead of the arguments themselves. This ensures that all dynamic futures have a constant size, regardless of the amount of data they contain.
DynamicRecord
A dynamic record is a fixed-size representation of a record. Like static Records, a dynamic record contains an owner, nonce, and a version. However, instead of storing the full data, it only stores the Merkle root of the data. This ensures that all dynamic records have a constant size, regardless of the amount of data they contain.
Future
A future.
HeaderLeaf
Identifier
An identifier is an immutable UTF-8 string, represented as a constant field element in the circuit.
ProgramID
A program ID is of the form {name}.{network}. If no network-level domain is specified, the default network is used.
Record
Request
Response
StatePath
The state path proves existence of the transition leaf to either a global or local state root.
TransactionLeaf
TransitionLeaf

Enums

Access
A helper type for accessing an entry in a register, struct, array, or record.
Argument
An argument passed into a future.
Entry
An entry stored in program data.
InputID
Literal
The literal enum represents all supported circuit types in snarkVM.
OutputID
Owner
A value stored in program data.
Plaintext
Value

Traits

Cast
Unary operator for casting values of one type to another.
CastLossy
Unary operator for casting values of one type to another, with lossy truncation.
Visibility

Functions

compute_function_id
Compute the function ID as Hash(network_id, program_id.len(), program_id, function_name.len(), function_name).

Type Aliases

RecordDataTree
The record data tree.