pub struct DynamicFuture<A: Aleo> { /* private fields */ }Expand description
A dynamic future is a fixed-size representation of a future. Like static
Futures, a dynamic future contains a program name, program network, and function name. These
are however represented as Field elements as opposed to Identifiers to
ensure a fixed size. Dynamic futures also store a checksum of the
arguments to the future instead of the arguments themselves. This ensures
that all dynamic futures have a constant size, regardless of the amount of
data they contain.
Note: The checksum is never computed in circuit. It is computed in console
as truncate_252(Sha3_256(length_prefix || type_prefixed_argument_bits)) and
injected as a witness field element.
Implementations
Sourceimpl<A: Aleo> DynamicFuture<A>
impl<A: Aleo> DynamicFuture<A>
Sourcepub const fn program_name(&self) -> &Field<A>
pub const fn program_name(&self) -> &Field<A>
Returns the program name.
Sourcepub const fn program_network(&self) -> &Field<A>
pub const fn program_network(&self) -> &Field<A>
Returns the program network.
Sourcepub const fn function_name(&self) -> &Field<A>
pub const fn function_name(&self) -> &Field<A>
Returns the function name.