Request

Struct Request 

pub struct Request<A: Aleo> { /* private fields */ }

Implementations

Source

impl<A: Aleo> Request<A>

pub fn to_tpk(&self) -> Group<A>

Returns the transition public key tpk.

Source

impl<A: Aleo> Request<A>

pub fn verify( &self, input_types: &[ValueType<A::Network>], tpk: &Group<A>, root_tvk: Option<Field<A>>, is_root: Boolean<A>, program_checksum: Option<Field<A>>, ) -> Boolean<A>

Returns true if the input IDs are derived correctly, the input records all belong to the signer, and the signature is valid.

Verifies (challenge == challenge’) && (address == address’) && (serial_numbers == serial_numbers’) where: challenge’ := HashToScalar(r * G, pk_sig, pr_sig, signer, [tvk, tcm, function ID, is_root, program checksum?, input IDs]) The program checksum must be provided if the program has a constructor and should not be provided otherwise.

pub fn check_input_ids<const CREATE_MESSAGE: bool>( network_id: &U16<A>, program_id: &ProgramID<A>, function_name: &Identifier<A>, input_ids: &[InputID<A>], inputs: &[Value<A>], input_types: &[ValueType<A::Network>], signer: &Address<A>, sk_tag: &Field<A>, tvk: &Field<A>, tcm: &Field<A>, signature: Option<&Signature<A>>, function_id: Option<Field<A>>, ) -> (Boolean<A>, Option<Vec<Field<A>>>)

Returns true if the inputs match their input IDs. Note: This method does not perform signature checks.

The function_id parameter is optional for backwards compatibility. When None, the function ID is computed from the network ID, program ID, and function name. When Some, the provided function ID is used directly. This is critical for dynamic dispatch where the function ID must be passed in to ensure circuit size does not depend on the length of the program or function name.

Source

impl<A: Aleo> Request<A>

pub const fn signer(&self) -> &Address<A>

Returns the request signer.

pub const fn network_id(&self) -> &U16<A>

Returns the network ID.

pub const fn program_id(&self) -> &ProgramID<A>

Returns the program ID.

pub const fn function_name(&self) -> &Identifier<A>

Returns the function name.

pub fn input_ids(&self) -> &[InputID<A>]

Returns the input IDs for the transition.

pub fn inputs(&self) -> &[Value<A>]

Returns the function inputs.

pub const fn signature(&self) -> &Signature<A>

Returns the signature for the transition.

pub const fn sk_tag(&self) -> &Field<A>

Returns the tag secret key.

pub const fn tvk(&self) -> &Field<A>

Returns the transition view key.

pub const fn tcm(&self) -> &Field<A>

Returns the transition commitment.

pub const fn scm(&self) -> &Field<A>

Returns the signer commitment.

pub fn is_dynamic(&self) -> bool

Returns whether or not the request is dynamic.