A dynamic future is a fixed-size representation of a future. Like static
Futures, a dynamic future contains a program name, program network, and function name. These
are however represented as Field elements as opposed to Identifiers to
ensure a fixed size. Dynamic futures also store a checksum of the
arguments to the future instead of the arguments themselves. This ensures
that all dynamic futures have a constant size, regardless of the amount of
data they contain.
A dynamic record is a fixed-size representation of a record. Like static
Records, a dynamic record contains an owner, nonce, and a version.
However, instead of storing the full data, it only stores the Merkle root of
the data. This ensures that all dynamic records have a constant size,
regardless of the amount of data they contain.