pub struct DynamicRecord<A: Aleo> { /* private fields */ }Expand description
A dynamic record is a fixed-size representation of a record. Like static
Records, a dynamic record contains an owner, nonce, and a version.
However, instead of storing the full data, it only stores the Merkle root of
the data. This ensures that all dynamic records have a constant size,
regardless of the amount of data they contain.
Suppose we have the following record with two data entries:
record foo:
owner as address.private;
microcredits as u64.private;
memo as [u8; 32u32].public;The leaves of its Merkle tree are computed as follows:
L_0 := HashPSD8(ToField(name_0) || ToFields(entry_0))
L_1 := HashPSD8(ToField(name_1) || ToFields(entry_1))where name_i is the field encoding of the entry identifier (e.g. "microcredits" → Field),
and ToFields encodes the entry’s mode and plaintext variant.
The tree has depth RECORD_DATA_TREE_DEPTH = 5 and is constructed with
path hasher HashPSD2 and the padding scheme outlined in
snarkVM’s MerkleTree.
Implementations
Sourceimpl<A: Aleo> DynamicRecord<A>
impl<A: Aleo> DynamicRecord<A>
Sourceimpl<A: Aleo> DynamicRecord<A>
impl<A: Aleo> DynamicRecord<A>
Sourcepub const fn data(&self) -> Option<&RecordData<A::Network>>
pub const fn data(&self) -> Option<&RecordData<A::Network>>
Returns the console record data.
Sourceimpl<A: Aleo> DynamicRecord<A>
impl<A: Aleo> DynamicRecord<A>
Sourcepub fn from_record(record: &Record<A, Plaintext<A>>) -> Result<Self>
pub fn from_record(record: &Record<A, Plaintext<A>>) -> Result<Self>
Creates a dynamic record from a static one.
Sourcepub fn merkleize_data(
data: &IndexMap<Identifier<A>, Entry<A, Plaintext<A>>>,
) -> Result<RecordDataTree<A>>
pub fn merkleize_data( data: &IndexMap<Identifier<A>, Entry<A, Plaintext<A>>>, ) -> Result<RecordDataTree<A>>
Serializes the given (ordered) entries to field elements, prepends an identifier tag
per entry, and computes the Merkle tree over the resulting leaves. More details on
the structure of the tree can be found in DynamicRecord.