pub struct Request<A: Aleo> { /* private fields */ }Implementations
Sourceimpl<A: Aleo> Request<A>
impl<A: Aleo> Request<A>
Sourcepub fn verify(
&self,
input_types: &[ValueType<A::Network>],
tpk: &Group<A>,
root_tvk: Option<Field<A>>,
is_root: Boolean<A>,
program_checksum: Option<Field<A>>,
) -> Boolean<A>
pub fn verify( &self, input_types: &[ValueType<A::Network>], tpk: &Group<A>, root_tvk: Option<Field<A>>, is_root: Boolean<A>, program_checksum: Option<Field<A>>, ) -> Boolean<A>
Returns true if the input IDs are derived correctly, the input records all belong to the signer,
and the signature is valid.
Verifies (challenge == challenge’) && (address == address’) && (serial_numbers == serial_numbers’) where: challenge’ := HashToScalar(r * G, pk_sig, pr_sig, signer, [tvk, tcm, function ID, is_root, program checksum?, input IDs]) The program checksum must be provided if the program has a constructor and should not be provided otherwise.
Sourcepub fn check_input_ids<const CREATE_MESSAGE: bool>(
network_id: &U16<A>,
program_id: &ProgramID<A>,
function_name: &Identifier<A>,
input_ids: &[InputID<A>],
inputs: &[Value<A>],
input_types: &[ValueType<A::Network>],
signer: &Address<A>,
sk_tag: &Field<A>,
tvk: &Field<A>,
tcm: &Field<A>,
signature: Option<&Signature<A>>,
function_id: Option<Field<A>>,
) -> (Boolean<A>, Option<Vec<Field<A>>>)
pub fn check_input_ids<const CREATE_MESSAGE: bool>( network_id: &U16<A>, program_id: &ProgramID<A>, function_name: &Identifier<A>, input_ids: &[InputID<A>], inputs: &[Value<A>], input_types: &[ValueType<A::Network>], signer: &Address<A>, sk_tag: &Field<A>, tvk: &Field<A>, tcm: &Field<A>, signature: Option<&Signature<A>>, function_id: Option<Field<A>>, ) -> (Boolean<A>, Option<Vec<Field<A>>>)
Returns true if the inputs match their input IDs.
Note: This method does not perform signature checks.
The function_id parameter is optional for backwards compatibility. When None, the
function ID is computed from the network ID, program ID, and function name. When Some,
the provided function ID is used directly. This is critical for dynamic dispatch where the
function ID must be passed in to ensure circuit size does not depend on the length of the
program or function name.
Sourceimpl<A: Aleo> Request<A>
impl<A: Aleo> Request<A>
Sourcepub const fn network_id(&self) -> &U16<A>
pub const fn network_id(&self) -> &U16<A>
Returns the network ID.
Sourcepub const fn program_id(&self) -> &ProgramID<A>
pub const fn program_id(&self) -> &ProgramID<A>
Returns the program ID.
Sourcepub const fn function_name(&self) -> &Identifier<A>
pub const fn function_name(&self) -> &Identifier<A>
Returns the function name.
Sourcepub fn is_dynamic(&self) -> bool
pub fn is_dynamic(&self) -> bool
Returns whether or not the request is dynamic.